onboarding/onboarding_step library

Classes

OnboardingStep
Represents a single step in the onboarding flow.

Enums

ArrowPosition
Position of the tooltip arrow relative to the tooltip container.
OnboardingTooltipPosition
Where the tooltip should appear relative to the target.