arrowAnchorKeys property
Optional list matching arrowPositions; when provided, each arrow will be horizontally aligned to the center of the corresponding key's widget.
Implementation
final List<GlobalKey>? arrowAnchorKeys;
Optional list matching arrowPositions; when provided, each arrow will be horizontally aligned to the center of the corresponding key's widget.
final List<GlobalKey>? arrowAnchorKeys;