targetClickables property

Map<GlobalKey<State<StatefulWidget>>, bool>? targetClickables
final

Controls whether touches on each target area pass through the overlay. When omitted or when a key is absent in the map, the target is clickable (passes through).

Implementation

final Map<GlobalKey, bool>? targetClickables;