allowTouchThrough property
When false, touches inside this target hole will be absorbed by the overlay.
Implementation
final bool allowTouchThrough;
When false, touches inside this target hole will be absorbed by the overlay.
final bool allowTouchThrough;