SpotlightService class
Service that manages spotlight overlays to highlight specific UI elements.
The spotlight creates a dimmed overlay with transparent holes around target widgets, drawing user attention to specific parts of the interface.
- Inheritance
-
- Object
- ChangeNotifier
- SpotlightService
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasListeners → bool
-
Whether any listeners are currently registered.
no setterinherited
- isShowing → bool
-
Whether a spotlight overlay is currently being displayed.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addListener(
VoidCallback listener) → void -
Register a closure to be called when the object changes.
inherited
-
dispose(
) → void -
Discards any resources used by the object. After this is called, the
object is not in a usable state and should be discarded (calls to
addListener will throw after the object is disposed).
inherited
-
hide(
) → Future< void> - Hides the currently displayed spotlight with an animation.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyListeners(
) → void -
Call all the registered listeners.
inherited
-
removeListener(
VoidCallback listener) → void -
Remove a previously registered closure from the list of closures that are
notified when the object changes.
inherited
-
show(
BuildContext context, {required List< SpotlightTarget> targets, List<Rect> ? extraHoles, List<Path> ? extraHolePaths, SpotlightStyle style = const SpotlightStyle()}) → Future<void> -
Shows a spotlight overlay highlighting the given
targets. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited